==> img0ch-2.1.11.tar.bz2: img0ch/_template/zeromin2/bbs_load_special_threads.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<?cs include:"zeromin2/thread_right_menu.cs" ?>

<div id="main">

<form id="specialThreadsContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">インデックス</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">スレッド整理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_special_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">特殊スレッド整理</a>
</div>

<h1>特殊スレッド整理</h1>

<?cs if:Code0 ?>
<?cs if:Done_bbs_create_special_thread ?><div class="noticeSuccess" id="notify"><p><?cs if:IsAdded ?>特殊スレッドの追記を行いました<?cs else ?>特殊スレッドの新規作成を行いました<?cs /if ?></p></div><?cs /if ?>
<?cs if:Done_bbs_remove_thread ?><div class="noticeSuccess" id="notify"><p>特殊スレッドを削除しました</p></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>操作対象のスレッドが選択されていません</p></div><?cs /if ?>
<?cs if:Code3 ?><div class="noticeFailed" id="notify"><p>特殊スレッド書き込み中にエラーが発生しました<br /><?cs var:Error ?></p></div><?cs /if ?>
<?cs /if ?>

<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" charset="UTF-8">
//<![CDATA[
jQuery(function(){
    jQuery("input[@name='FROM']").attr({ "value": jQuery.cookie("img0ch_name") });
    jQuery("input[@name='mail']").attr({ "value": jQuery.cookie("img0ch_mail") });
});
function showPageHideForm() {
    jQuery('div#writeForm').hide();
    jQuery('div#specialThreads').show();
    return true;
}
function showFormHidePage() {
    jQuery('div#specialThreads').hide();
    jQuery('div#writeForm').show();
    return true;
}
//]]>
</script>

<p>
現在掲示板に存在する特殊スレッド(通称924)を操作します。
</p>

<p>
チェックされたスレッドの<input type="submit" value="削除" /><br />
(「以下のスレッドを削除する」を選択した場合のみ)
</p>

<p>
<input type="radio" id="remove" name="method" value="remove_thread" checked="checked" onclick="showPageHideForm()"  />
<label for="remove" style="display:inline;">以下のスレッドを削除する</label>

<div id="specialThreads">

ページ単位：
<input type="text" name="item" size="5" value="<?cs var:html_escape(Item) ?>" /><br />
(&nbsp;<?cs var:html_escape(Total) ?>件&nbsp;-&nbsp;現在<?cs var:html_escape(Current) ?>ページ目&nbsp;)<br />
<span class="page">
<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
<?cs each:item = Pages ?>
<a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
</span>
</p>

<table class="simple">
  <thead>
    <tr><td><input type="checkbox" name="" value="" onclick="Zeromin2.selectAllCheckbox( this, 'thread' )" /></td><td>スレッド名</td><td>レス数</td><td>スレッドキー</td></tr>
  </thead>
  <tbody>
  <?cs each:item = Entries ?>
    <tr><td><input type="checkbox" name="thread" value="<?cs var:html_escape(item.key) ?>" /></td><td><a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=load&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(item.key) ?>&amp;option=l50&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:item.subject ?></a></td><td><?cs var:html_escape(item.count) ?></td><td title="<?cs var:html_escape(item.key) ?>"><?cs var:html_escape(item.key) ?></td></tr>
  <?cs /each ?>
  </tbody>
</table>

</div>

<p>
 <input type="radio" id="write" name="method" value="create_special_thread" onclick="showFormHidePage()" />
 <label for="write" style="display:inline;">スレッドの作成またはレスを行う</label><br />
 <div id="writeForm" style="display:none">
  タイトル&nbsp;<input type="text" name="subject" size="25" value="" /><br />
  名前&nbsp;<input type="text" name="FROM" size=19 value="" /><br />
  E-mail&nbsp;<input type="text" name="mail" size=19 value="" /><br />
  <textarea rows="5" cols="64" name="MESSAGE"></textarea><br />
  スレッドの対象(レスを追記する場合)<br /><select name="key">
   <option value="key">(スレッドを新規作成)</option>
   <?cs each:item = Entries ?><option value="<?cs var:html_escape(item.key) ?>"><?cs var:item.subject ?></option>
  <?cs /each ?></select><br />
  <input type="submit" value="スレッド作成またはレス追記"><br />
 </div>
</p>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="bbs" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBSName) ?>" />
<input type="hidden" name="OK" value="load_special_threads" />
<input type="hidden" name="NG" value="load_special_threads" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-2.1.21.tar.bz2: img0ch/_template/zeromin2/bbs_load_special_threads.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<?cs include:"zeromin2/thread_right_menu.cs" ?>

<div id="main">

<form id="specialThreadsContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">インデックス</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">スレッド整理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_special_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">特殊スレッド整理</a>
</div>

<h1>特殊スレッド整理</h1>

<?cs if:Code0 ?>
<?cs if:Done_bbs_create_special_thread ?><div class="noticeSuccess" id="notify"><p><?cs if:IsAdded ?>特殊スレッドの追記を行いました<?cs else ?>特殊スレッドの新規作成を行いました<?cs /if ?></p></div><?cs /if ?>
<?cs if:Done_bbs_remove_thread ?><div class="noticeSuccess" id="notify"><p>特殊スレッドを削除しました</p></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>操作対象のスレッドが選択されていません</p></div><?cs /if ?>
<?cs if:Code3 ?><div class="noticeFailed" id="notify"><p>特殊スレッド書き込み中にエラーが発生しました<br /><?cs var:Error ?></p></div><?cs /if ?>
<?cs /if ?>

<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js" charset="UTF-8"></script>
<script type="text/javascript" charset="UTF-8">
//<![CDATA[
jQuery(function(){
    jQuery("input[@name='FROM']").attr({ "value": jQuery.cookie("img0ch_name") });
    jQuery("input[@name='mail']").attr({ "value": jQuery.cookie("img0ch_mail") });
});
function showPageHideForm() {
    jQuery('div#writeForm').hide();
    jQuery('div#specialThreads').show();
    return true;
}
function showFormHidePage() {
    jQuery('div#specialThreads').hide();
    jQuery('div#writeForm').show();
    return true;
}
//]]>
</script>

<p>
現在掲示板に存在する特殊スレッド(通称924)を操作します。
</p>

<p>
チェックされたスレッドの<input type="submit" value="削除" /><br />
(「以下のスレッドを削除する」を選択した場合のみ)
</p>

<p>
<input type="radio" id="remove" name="method" value="remove_thread" checked="checked" onclick="showPageHideForm()"  />
<label for="remove" style="display:inline;">以下のスレッドを削除する</label>

<div id="specialThreads">

ページ単位：
<input type="text" name="item" size="5" value="<?cs var:html_escape(Item) ?>" /><br />
(&nbsp;<?cs var:html_escape(Total) ?>件&nbsp;-&nbsp;現在<?cs var:html_escape(Current) ?>ページ目&nbsp;)<br />
<span class="page">
<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
<?cs each:item = Pages ?>
<a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
</span>
</p>

<table class="simple">
  <thead>
    <tr><td><input type="checkbox" name="" value="" onclick="Zeromin2.selectAllCheckbox( this, 'thread' )" /></td><td>スレッド名</td><td>レス数</td><td>スレッドキー</td></tr>
  </thead>
  <tbody>
  <?cs each:item = Entries ?>
    <tr><td><input type="checkbox" name="thread" value="<?cs var:html_escape(item.key) ?>" /></td><td><a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=load&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(item.key) ?>&amp;option=l50&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:item.subject ?></a></td><td><?cs var:html_escape(item.count) ?></td><td title="<?cs var:html_escape(item.key) ?>"><?cs var:html_escape(item.key) ?></td></tr>
  <?cs /each ?>
  </tbody>
</table>

</div>

<p>
 <input type="radio" id="write" name="method" value="create_special_thread" onclick="showFormHidePage()" />
 <label for="write" style="display:inline;">スレッドの作成またはレスを行う</label><br />
 <div id="writeForm" style="display:none">
  タイトル&nbsp;<input type="text" name="subject" size="25" value="" /><br />
  名前&nbsp;<input type="text" name="FROM" size=19 value="" /><br />
  E-mail&nbsp;<input type="text" name="mail" size=19 value="" /><br />
  <textarea rows="5" cols="64" name="MESSAGE"></textarea><br />
  スレッドの対象(レスを追記する場合)<br /><select name="key">
   <option value="key">(スレッドを新規作成)</option>
   <?cs each:item = Entries ?><option value="<?cs var:html_escape(item.key) ?>"><?cs var:item.subject ?></option>
  <?cs /each ?></select><br />
  <input type="submit" value="スレッド作成またはレス追記"><br />
 </div>
</p>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="bbs" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBSName) ?>" />
<input type="hidden" name="OK" value="load_special_threads" />
<input type="hidden" name="NG" value="load_special_threads" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
